/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"],\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"range"
    "_mean\":{\"type\":\"array\",\"description\":\"Mean range [m]\",\"items\":{\"type\":"
    "\"number\"}},\"angle\":{\"type\":\"array\",\"description\":\"Angle [deg]\",\"items\""
    ":{\"type\":\"number\"}},\"amplitude_mean\":{\"type\":\"array\",\"description\":\"Me"
    "an amplitude [dB]\",\"items\":{\"type\":\"number\"}}},\"title\":\"Angular Notch "
    "Filter\",\"description\":\"Angular notch filter parameters for window "
    "glass echoes\"}"
    ,
    /* example: */
    "{\"range_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0"
    ".068,0.0675,0.06475],\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,"
    "22.0,23.0,24.0],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,"
    "2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"temperature\",\"pressure\",\"rel_humidity\",\""
    "pressure_sl\",\"amsl\",\"group_velocity\",\"attenuation\",\"wavelength\"],\"$sch"
    "ema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"amsl\":{\""
    "type\":\"number\",\"description\":\"Height above mean sea level (AMSL) "
    "[m]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature along "
    "measurement path "
    "[\\u00b0C]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser "
    "wavelength "
    "[nm]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group velocity"
    " of laser beam "
    "[m/s]\"},\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure along "
    "measurment path [mbar]\"}},\"title\":\"Atmospheric "
    "Parameters\",\"description\":\"Atmospheric parameters\"}"
    ,
    /* example: */
    "{\"amsl\":0,\"temperature\":7,\"wavelength\":1550,\"group_velocity\":299711000"
    ".0,\"pressure_sl\":970,\"attenuation\":0.028125,\"rel_humidity\":63,\"pressur"
    "e\":970}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"beam_exit_diameter\",\"beam_divergence\"],\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"beam"
    "_exit_diameter\":{\"type\":\"number\",\"exclusiveMinimum\":false,\"description"
    "\":\"Beam width at exit aperture [m]\",\"minimum\":0},\"beam_divergence\":{\"t"
    "ype\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Beam divergence "
    "in far field [rad]\",\"minimum\":0}},\"title\":\"Beam "
    "Geometry\",\"description\":\"Laser beam geometry details\"}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"types\"],\"definitions\":{\"round_corner_cub"
    "e_prism\":{\"type\":\"object\",\"description\":\"round corner cube prism\",\"all"
    "Of\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"required\":[\"sha"
    "pe\",\"diameter\"],\"description\":\"round corner cube prism specific proper"
    "ties\",\"properties\":{\"diameter\":{\"type\":\"number\",\"exclusiveMinimum\":tru"
    "e,\"description\":\"diameter in "
    "meters\",\"minimum\":0},\"offset\":{\"type\":\"number\",\"description\":\"offset "
    "in meters, e.g. reflector constant "
    "(optional)\"},\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\""
    ",\"enum\":[\"round_corner_cube_prism\"]}}}]},\"chevron\":{\"type\":\"object\",\"d"
    "escription\":\"chevron\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\""
    ":\"object\",\"required\":[\"shape\",\"outside_edge_length\",\"thickness\"],\"desc"
    "ription\":\"chevron specific properties\",\"properties\":{\"thickness\":{\"typ"
    "e\":\"number\",\"exclusiveMinimum\":true,\"description\":\"thickness in "
    "meters\",\"minimum\":0},\"shape\":{\"type\":\"string\",\"description\":\"shape ide"
    "ntifier\",\"enum\":[\"chevron\"]},\"outside_edge_length\":{\"type\":\"number\",\"e"
    "xclusiveMinimum\":true,\"description\":\"length of the two outer edges in "
    "meters\",\"minimum\":0}}}]},\"common\":{\"type\":\"object\",\"required\":[\"name\","
    "\"shape\"],\"description\":\"common object properties\",\"properties\":{\"name\""
    ":{\"type\":\"string\",\"description\":\"unique type identifier\",\"minLength\":3"
    "},\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"enum\":[\"r"
    "ectangle\",\"checkerboard2x2\",\"chevron\",\"circular_disk\",\"cylinder\",\"sphe"
    "re\",\"round_corner_cube_prism\"]},\"description\":{\"type\":\"string\",\"descri"
    "ption\":\"string describing the "
    "object\"},\"surface_type\":{\"type\":\"string\",\"description\":\"surface "
    "material type\",\"enum\":[\"retro_reflective_foil\",\"diffuse\"]}}},\"rectangl"
    "e\":{\"type\":\"object\",\"description\":\"rectangle\",\"allOf\":[{\"$ref\":\"#/defi"
    "nitions/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"length\",\"width\""
    "],\"description\":\"rectangle specific properties\",\"properties\":{\"length\""
    ":{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"length in met"
    "ers\",\"minimum\":0},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\"]},\"widt"
    "h\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"width in me"
    "ters\",\"minimum\":0}}}]},\"cylinder\":{\"type\":\"object\",\"description\":\"cyli"
    "nder\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"requi"
    "red\":[\"shape\",\"diameter\",\"height\"],\"description\":\"cylinder specific pr"
    "operties\",\"properties\":{\"diameter\":{\"type\":\"number\",\"exclusiveMinimum\""
    ":true,\"description\":\"diameter in meters\",\"minimum\":0},\"height\":{\"type\""
    ":\"number\",\"exclusiveMinimum\":true,\"description\":\"height in "
    "meters\",\"minimum\":0},\"shape\":{\"type\":\"string\",\"description\":\"shape ide"
    "ntifier\",\"enum\":[\"cylinder\"]}}}]},\"sphere\":{\"type\":\"object\",\"descripti"
    "on\":\"sphere\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\""
    ",\"required\":[\"shape\",\"diameter\"],\"description\":\"sphere specific proper"
    "ties\",\"properties\":{\"diameter\":{\"type\":\"number\",\"exclusiveMinimum\":tru"
    "e,\"description\":\"diameter in "
    "meters\",\"minimum\":0},\"shape\":{\"type\":\"string\",\"description\":\"shape ide"
    "ntifier\",\"enum\":[\"sphere\"]}}}]},\"checkerboard2x2\":{\"type\":\"object\",\"de"
    "scription\":\"checkerboard 2 by 2\",\"allOf\":[{\"$ref\":\"#/definitions/commo"
    "n\"},{\"type\":\"object\",\"required\":[\"shape\",\"square_length\"],\"description"
    "\":\"checkerboard specific properties\",\"properties\":{\"shape\":{\"type\":\"st"
    "ring\",\"description\":\"shape identifier\",\"enum\":[\"checkerboard2x2\"]},\"sq"
    "uare_length\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"l"
    "ength of a square of the checkerboard in meters\",\"minimum\":0}}}]},\"cir"
    "cular_disk\":{\"type\":\"object\",\"description\":\"circular disk\",\"allOf\":[{\""
    "$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"di"
    "ameter\"],\"description\":\"circular disk specific properties\",\"properties"
    "\":{\"diameter\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\""
    "diameter in "
    "meters\",\"minimum\":0},\"offset\":{\"type\":\"number\",\"description\":\"offset "
    "in meters, e.g. reflector constant "
    "(optional)\"},\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\""
    ",\"enum\":[\"circular_disk\"]}}}]}},\"properties\":{\"types\":{\"type\":\"array\","
    "\"uniqueItems\":true,\"items\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/defini"
    "tions/rectangle\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/"
    "definitions/chevron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\""
    "#/definitions/cylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/de"
    "finitions/round_corner_cube_prism\"}]}}},\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"title\":\"Control Object "
    "Catalog\",\"description\":\"List of control object type definitions\"}"
    ,
    /* example: */
    "{\"types\":[{\"name\":\"Rectangle "
    "60x30\",\"shape\":\"rectangle\",\"description\":\"Rectangle (60cm x "
    "30cm)\",\"length\":0.6,\"width\":0.3},{\"name\":\"Rectangle "
    "80x40\",\"shape\":\"rectangle\",\"description\":\"Rectangle (80cm x "
    "40cm)\",\"length\":0.8,\"width\":0.4},{\"name\":\"Checkerboard2x2 "
    "30\",\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square "
    "length: 30cm)\",\"square_length\":0.3},{\"name\":\"Checkerboard2x2 "
    "50\",\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square "
    "length: 50cm)\",\"square_length\":0.5},{\"name\":\"Chevron "
    "24''/4''\",\"shape\":\"chevron\",\"thickness\":0.1016,\"description\":\"Chevron "
    "(a=24''; b=4'')\",\"outside_edge_length\":0.6096},{\"name\":\"Circular Disk "
    "50\",\"shape\":\"circular_disk\",\"description\":\" Circular Disk (diameter: "
    "50cm)\",\"surface_type\":\"diffuse\",\"diameter\":0.5},{\"name\":\"RIEGL flat "
    "reflector 50 mm\",\"diameter\":0.05,\"offset\":0.0,\"shape\":\"circular_disk\","
    "\"surface_type\":\"retro_reflective_foil\",\"description\":\"flat circular "
    "reflector from retro-reflective foil\"},{\"name\":\"RIEGL flat reflector "
    "100 mm\",\"diameter\":0.1,\"offset\":0.0,\"shape\":\"circular_disk\",\"surface_t"
    "ype\":\"retro_reflective_foil\",\"description\":\"flat circular reflector "
    "from retro-reflective foil\"},{\"name\":\"RIEGL flat reflector 150 mm\",\"di"
    "ameter\":0.15,\"offset\":0.0,\"shape\":\"circular_disk\",\"surface_type\":\"retr"
    "o_reflective_foil\",\"description\":\"flat circular reflector from "
    "retro-reflective foil\"},{\"name\":\"RIEGL cylindrical reflector 50 "
    "mm\",\"diameter\":0.05,\"height\":0.05,\"description\":\"cylindrical reflector"
    " from retro-reflective foil\",\"shape\":\"cylinder\",\"surface_type\":\"retro_"
    "reflective_foil\"},{\"name\":\"RIEGL cylindrical reflector 100 "
    "mm\",\"diameter\":0.1,\"height\":0.1,\"description\":\"cylindrical reflector "
    "from retro-reflective foil\",\"shape\":\"cylinder\",\"surface_type\":\"retro_r"
    "eflective_foil\"},{\"name\":\"Sphere 200 "
    "mm\",\"shape\":\"sphere\",\"description\":\"Sphere (diameter: 200 "
    "mm)\",\"diameter\":0.2},{\"name\":\"Corner Cube Prism 50 mm\",\"shape\":\"round_"
    "corner_cube_prism\",\"offset\":0.0,\"description\":\"round corner cube "
    "prism\",\"diameter\":0.05}],\"comments\":[\"This file contains a list of "
    "control object types (aka. 'catalog').\",\"Each type is described by an "
    "object,\",\"which must contain at least the following parameters:\",\"  - "
    "name: unique identifier of the type\",\"  - shape: one of the following "
    "supported shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\""
    "      - chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - "
    "sphere\",\"      - round_corner_cube_prism\",\"Depending on 'shape', the "
    "following parameters must/may be specified:\",\"  - rectangle:\",\"      -"
    " length: length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about the control object "
    "reference file\",\"properties\":{\"reference_file\":{\"type\":\"object\",\"requi"
    "red\":[\"file_uuid\",\"file_path\"],\"description\":\"Reference to a control "
    "object "
    "file\",\"properties\":{\"file_path\":{\"type\":\"string\",\"description\":\"Path "
    "of the control object file relative to referring "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC 4122)\"}}}},\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"title\":\"Control Object Reference "
    "file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"amplitude\",\"detection_probability\"],\"$sc"
    "hema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"detecti"
    "on_probability\":{\"type\":\"array\",\"description\":\"Detection probability ["
    "0..1]\",\"items\":{\"type\":\"number\"}},\"amplitude\":{\"type\":\"array\",\"descrip"
    "tion\":\"Amplitude [dB]\",\"items\":{\"type\":\"number\"}}},\"title\":\"Detection "
    "Probability\",\"description\":\"Detection probability as a function of "
    "amplitude\"}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"device_type\",\"serial_number\"],\"$schema\":"
    "\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"channel_numbe"
    "r\":{\"type\":\"integer\",\"exclusiveMinimum\":false,\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"minimum\":0}"
    ",\"device_type\":{\"type\":\"string\",\"description\":\"Device type identifier "
    "(e.g. "
    "VZ-400i)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device "
    "build "
    "variant\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"}},\"title\":\"Device Information\",\"description\":\"Details about "
    "the device used to acquire the point cloud\"}"
    ,
    /* example: */
    "{\"channel_number\":0,\"device_type\":\"VZ-400i\",\"serial_number\":\"S2221234\""
    ",\"device_build\":\"\",\"channel_text\":\"\",\"device_name\":\"Scanner 1\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"primary\"],\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"properties\":{\"primary\":{\"type\":\"object\",\"requir"
    "ed\":[\"ID\",\"content\"],\"description\":\"Primary device geometry structure "
    "(mandatory)\",\"properties\":{\"content\":{\"type\":\"array\",\"description\":\"In"
    "ternal calibration values\",\"items\":{\"type\":\"number\"}},\"ID\":{\"type\":\"ar"
    "ray\",\"maxItems\":2,\"description\":\"Structure identifier\",\"items\":{\"type\""
    ":\"integer\"},\"minItems\":2}}},\"secondary\":{\"type\":\"object\",\"required\":[\""
    "ID\",\"content\"],\"description\":\"Additional device geometry structure (op"
    "tional)\",\"properties\":{\"content\":{\"type\":\"array\",\"description\":\"Intern"
    "al calibration values\",\"items\":{\"type\":\"number\"}},\"ID\":{\"type\":\"array\""
    ",\"maxItems\":2,\"description\":\"Structure identifier\",\"items\":{\"type\":\"in"
    "teger\"},\"minItems\":2}}},\"amu\":{\"type\":\"object\",\"description\":\"Angle "
    "Measurement Unit\",\"properties\":{\"lineCC\":{\"type\":\"number\",\"exclusiveMi"
    "nimum\":false,\"description\":\"Line Circle Count (number of LSBs per full"
    " rotation about line axis)\",\"minimum\":0},\"frameCC\":{\"type\":\"number\",\"e"
    "xclusiveMinimum\":false,\"description\":\"Frame Circle Count (number of "
    "LSBs per full rotation about frame "
    "axis)\",\"minimum\":0}}}},\"title\":\"Device "
    "Geometry\",\"description\":\"Scanner device geometry details\"}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[4,0]},\"secondary\":{\"content\":[0],\"ID\":"
    "[91,0]},\"amu\":{\"lineCC\":124000,\"frameCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"primary\"],\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"properties\":{\"primary\":{\"type\":\"object\",\"requir"
    "ed\":[\"ID\",\"content\"],\"description\":\"Primary device geometry structure "
    "(mandatory)\",\"properties\":{\"content\":{\"type\":\"array\",\"description\":\"In"
    "ternal calibration values\",\"items\":{\"type\":\"number\"}},\"ID\":{\"type\":\"ar"
    "ray\",\"maxItems\":2,\"description\":\"Structure identifier\",\"items\":{\"type\""
    ":\"integer\"},\"minItems\":2}}}},\"title\":\"Device Geometry Passive "
    "Channel\",\"description\":\"Scanner passive channel device geometry "
    "details\"}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Limits of the measured values output "
    "by the device. The limits depend on the device type, measurement "
    "program and/or scan pattern.\",\"properties\":{\"reflectance_minimum\":{\"ty"
    "pe\":\"number\",\"description\":\"Minimum possible reflectance in "
    "dB.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape deviation.\"},\"amplitude_minimum\":{\"type\":\"number\""
    ",\"description\":\"Minimum possible amplitude in "
    "dB.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible"
    " range in "
    "meters.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"},\"mta_zone_count_maximum\":{\"type\":\"nu"
    "mber\",\"description\":\"Maximum number of MTA "
    "zones.\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible amplitude in dB.\"},\"background_radiation_maximum\":{\"type\":\"nu"
    "mber\",\"description\":\"Maximum possible background radiation.\"},\"reflect"
    "ance_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible "
    "reflectance in "
    "dB.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible"
    " range in meters.\"},\"background_radiation_minimum\":{\"type\":\"number\",\"d"
    "escription\":\"Minimum possible background radiation.\"},\"echo_count_maxi"
    "mum\":{\"type\":\"number\",\"description\":\"Maximum number of echoes a laser "
    "shot can have.\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"title\":\"Device Output Limits\"}"
    ,
    /* example: */
    "{\"reflectance_maximum\":100.0,\"mta_zone_count_maximum\":7,\"background_ra"
    "diation_minimum\":0,\"deviation_maximum\":32767,\"range_maximum\":10000.0,\""
    "background_radiation_maximum\":0,\"deviation_minimum\":-1,\"amplitude_mini"
    "mum\":0.0,\"range_minimum\":2.9,\"reflectance_minimum\":-100.0,\"amplitude_m"
    "aximum\":100.0}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"description\":\"Details about the devices used to "
    "acquire the point cloud (e.g. when merging point clouds of different d"
    "evices)\",\"items\":{\"type\":\"object\",\"required\":[\"device_type\",\"serial_nu"
    "mber\"],\"properties\":{\"channel_number\":{\"type\":\"integer\",\"exclusiveMini"
    "mum\":false,\"description\":\"Laser channel number (not defined or 0: "
    "single channel "
    "device)\",\"minimum\":0},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag "
    "that is set when the original 'riegl.device' entry in the source file "
    "was correctly "
    "signed.\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device "
    "build "
    "variant\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner systems)\"}}},\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Devices "
    "Information\"}"
    ,
    /* example: */
    "[{\"channel_number\":0,\"signed\":false,\"device_type\":\"VZ-400i\",\"serial_nu"
    "mber\":\"S2221234\",\"device_build\":\"\",\"channel_text\":\"\",\"device_name\":\"Sc"
    "anner 1\"},{\"channel_number\":1,\"signed\":true,\"device_type\":\"VQ-1560i-DW"
    "\",\"serial_number\":\"S2222680\",\"device_build\":\"\",\"channel_text\":\"\",\"devi"
    "ce_name\":\"Scanner 2\"},{\"channel_number\":2,\"signed\":true,\"device_type\":"
    "\"VQ-1560i-DW\",\"serial_number\":\"S2222680\",\"device_build\":\"\",\"channel_te"
    "xt\":\"\",\"device_name\":\"Scanner 3\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Dyntrig\",\"properties\":{\"scale\":{\"type\":\"number\",\"descr"
    "iption\":\"Scale in units of dB, for calculation of line: line number N="
    "(amplitude-offset)/scale\"},\"pre\":{\"type\":\"object\",\"required\":[\"nc\",\"a\""
    "],\"description\":\"Dyntrig pre values\",\"properties\":{\"a\":{\"type\":\"array\""
    ",\"description\":\"...\",\"maxItems\":2080,\"items\":{\"type\":\"number\"},\"minIte"
    "ms\":1},\"nc\":{\"type\":\"integer\",\"description\":\"Number of entries\",\"maxim"
    "um\":255,\"minimum\":0}}},\"tab\":{\"type\":\"array\",\"description\":\"...\",\"maxI"
    "tems\":128,\"items\":{\"type\":\"object\",\"required\":[\"thra1\",\"del1\",\"dec1\",\""
    "thra2\",\"del2\",\"dec2\"],\"description\":\"...\",\"properties\":{\"dec1\":{\"type\""
    ":\"number\",\"description\":\"Decay of post-trigger threshold after del1 in"
    " units of dB/m\"},\"thra2\":{\"type\":\"number\",\"description\":\"Pre-trigger "
    "threshold in units of "
    "dB\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of "
    "m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold in "
    "units of dB\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of "
    "pre-trigger threshold after del2 in units of "
    "dB/m\"}}},\"minItems\":1},\"offset\":{\"type\":\"number\",\"description\":\"Offset"
    " in units of dB, for calculation of line\"},\"post\":{\"type\":\"object\",\"re"
    "quired\":[\"nc\",\"a\"],\"description\":\"Dyntrig post values\",\"properties\":{\""
    "a\":{\"type\":\"array\",\"description\":\"...\",\"maxItems\":2080,\"items\":{\"type\""
    ":\"number\"},\"minItems\":1},\"nc\":{\"type\":\"integer\",\"description\":\"Number "
    "of entries\",\"maximum\":255,\"minimum\":0}}}},\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"title\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"scale\":1.0,\"pre\":{\"a\":[78,86,126,134,31],\"nc\":128},\"tab\":[{\"dec1\":0."
    "0,\"thra2\":0.0,\"del2\":0.0,\"del1\":0.0,\"thra1\":0.0,\"dec2\":0.0}],\"offset\":"
    "0.0,\"post\":{\"a\":[78,86,126,134,31],\"nc\":128}}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"echo_file\"],\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"properties\":{\"echo_file\":{\"type\":\"object\",\"re"
    "quired\":[\"file_extension\"],\"properties\":{\"file_uuid\":{\"type\":\"string\","
    "\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading dot\"}}}},\"title\":\"Echo "
    "Information\",\"description\":\"Details about echo files\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"additionalProperties\":false,\"definitions\":{\"channel\""
    ":{\"type\":\"object\",\"required\":[\"delay\",\"scale\",\"parameter\"],\"properties"
    "\":{\"delay\":{\"type\":\"number\",\"description\":\"delay calibration in "
    "seconds\"},\"scale\":{\"type\":\"number\",\"description\":\"amplitude calibratio"
    "n\"},\"a_lin\":{\"type\":\"number\",\"exclusiveMaximum\":false,\"exclusiveMinimu"
    "m\":false,\"minimum\":0,\"description\":\"relative linear amplitude range [0"
    "..1]\",\"maximum\":1},\"parameter\":{\"type\":\"object\",\"required\":[\"A\",\"B\",\"g"
    "amma\",\"omega\"],\"description\":\"parameters of the syswave exponential "
    "sum\",\"properties\":{\"B\":{\"type\":\"array\",\"description\":\"imaginary part "
    "of amplitude factor in units of full-scale\",\"items\":{\"type\":\"number\"}}"
    ",\"gamma\":{\"type\":\"array\",\"description\":\"decay in 1/second\",\"items\":{\"t"
    "ype\":\"number\"}},\"A\":{\"type\":\"array\",\"description\":\"real part of "
    "amplitude factor in units of full-scale\",\"items\":{\"type\":\"number\"}},\"o"
    "mega\":{\"type\":\"array\",\"description\":\"angular frequency in Hz\",\"items\":"
    "{\"type\":\"number\"}}}}}}},\"patternProperties\":{\"^[0-9]+$\":{\"description\""
    ":\"one field per channel, field name is channel index\",\"$ref\":\"#/defini"
    "tions/channel\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "title\":\"Exponential Decomposition\",\"description\":\"Details for "
    "exponential decomposition of full waveform data\"}"
    ,
    /* example: */
    "{\"0\":{\"delay\":3.783458418887631e-09,\"scale\":1.0,\"a_lin\":0.27,\"paramete"
    "r\":{\"B\":[-3.9813032150268555,0.08622030913829803,-0.3152860999107361],"
    "\"gamma\":[-1094726528.0,-769562752.0,-848000064.0],\"A\":[0.9772450923919"
    "678,0.3354335129261017,-1.312678575515747],\"omega\":[352020896.0,364792"
    "7552.0,-1977987072.0]}},\"1\":{\"delay\":3.5e-09,\"scale\":1.0,\"a_lin\":0.9,\""
    "parameter\":{\"B\":[-3.9,0.0,-0.3],\"gamma\":[-1094726528.0,-769562752.0,-8"
    "48000064.0],\"A\":[0.9,0.3,-1.3],\"omega\":[352020896.0,3647927552.0,-1977"
    "987072.0]}}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_"
    "high_power\",\"amplitude_db\",\"range_offset_sec_low_power\",\"range_offset_"
    "sec_high_power\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "properties\":{\"range_offset_sec_high_power\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\"}},\"amplitude_lsb_high_power\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\"}},\"range_offset_sec_low_power\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"number\"}},\"amplitude_db\":{\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\"}},\"amplitude_lsb_low_power\":{\"type\":\"array\",\"items\":{\"type\":\"numbe"
    "r\"}}},\"title\":\"Gaussian "
    "Decomposition\",\"description\":\"riegl.gaussian_decomposition contains "
    "information relevant for extracting calibrated amplitudes and "
    "calibrated ranges from a Gaussian decomposition of full waveform data."
    " This information is contained in a table with five columns. Two "
    "columns are to be used as input: amplitude_lsb_low_power and "
    "amplitude_lsb_high_power. The other three columns provide the outputs."
    " Amplitude_db gives the calibrated amplitude in the optical regime in "
    "decibels. The range offset columns provide additive range offsets, "
    "given in units of seconds, for each channel.\"}"
    ,
    /* example: */
    "{\"range_offset_sec_high_power\":[],\"amplitude_lsb_high_power\":[],\"range"
    "_offset_sec_low_power\":[],\"amplitude_db\":[],\"amplitude_lsb_low_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Point cloud georeferencing information"
    "\",\"properties\":{\"pose\":{\"type\":\"array\",\"maxItems\":4,\"description\":\"Coo"
    "rdinate Transformation Matrix to transform from File Coordinate System"
    " to Global Coordinate Reference System. 4x4 matrix stored as two "
    "dimensional array, row major order.\",\"items\":{\"type\":\"array\",\"maxItems"
    "\":4,\"description\":\"rows\",\"items\":{\"type\":\"number\",\"description\":\"colum"
    "ns\"},\"minItems\":4},\"minItems\":4},\"crs\":{\"type\":\"object\",\"description\":"
    "\"Global Coordinate Reference System. Please note that only 3D "
    "Cartesian Coordinate Systems are allowed.\",\"properties\":{\"name\":{\"type"
    "\":\"string\",\"description\":\"Coordinate reference system "
    "name\"},\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG "
    "code\",\"minimum\":0},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known "
    "Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan"
    "dards/wkt-crs)\"}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#"
    "\",\"title\":\"Geo Tag\"}"
    ,
    /* example: */
    "{\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063"
    "882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113"
    "8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0"
    ".0,0.0,0.0,1.0]],\"crs\":{\"name\":\"WGS84 "
    "Geocentric\",\"epsg\":4978,\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS"
    "84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\"
    "\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000"
    "000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.0000000000000"
    "0000000,AUTHORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAS"
    "T],AXIS[\\\"Z\\\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\"}}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Geometric "
    "scale factor applied to point coordinates\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"minimum\":0}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Parameters used for georeferencing of "
    "the point cloud\",\"properties\":{\"socs_to_body_matrix\":{\"type\":\"array\",\""
    "maxItems\":4,\"description\":\"Coordinate Transformation Matrix to "
    "transform from Scanner's Own Coordinate System to Body Coordinate "
    "System. 4x4 matrix stored as two dimensional array, row major order.\","
    "\"items\":{\"type\":\"array\",\"maxItems\":4,\"description\":\"rows\",\"items\":{\"ty"
    "pe\":\"number\",\"description\":\"columns\"},\"minItems\":4},\"minItems\":4},\"bod"
    "y_coordinate_system_type\":{\"type\":\"string\",\"description\":\"BODY "
    "coordinate frame (NED: North-East-Down, ENU: East-North-Up), default: "
    "NED\",\"enum\":[\"NED\",\"ENU\"]},\"socs_to_rocs_matrix\":{\"type\":\"array\",\"maxI"
    "tems\":4,\"description\":\"Coordinate Transformation Matrix to transform "
    "from Scanner's Own Coordinate System to Record Coordinate System. 4x4 "
    "matrix stored as two dimensional array, row major order.\",\"items\":{\"ty"
    "pe\":\"array\",\"maxItems\":4,\"description\":\"rows\",\"items\":{\"type\":\"number\""
    ",\"description\":\"columns\"},\"minItems\":4},\"minItems\":4},\"trajectory_file"
    "\":{\"type\":\"object\",\"required\":[\"file_extension\"],\"description\":\"Trajec"
    "tory data used for georeferencing of the point cloud\",\"properties\":{\"f"
    "ile_uuid\":{\"type\":\"string\",\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading dot\"}}},\"trajectory_offsets\":{\"typ"
    "e\":\"object\",\"description\":\"Correction offsets applied to the "
    "trajectory "
    "data\",\"properties\":{\"version\":{\"type\":\"integer\",\"description\":\"Meaning"
    " of offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_east\":{\"type\":\"number\",\"description\":\"[m]\""
    "},\"offset_yaw\":{\"type\":\"number\",\"description\":\"[deg]\"},\"offset_north\":"
    "{\"type\":\"number\",\"description\":\"[m]\"},\"offset_height\":{\"type\":\"number\""
    ",\"description\":\"[m]\"},\"offset_pitch\":{\"type\":\"number\",\"description\":\"["
    "deg]\"},\"offset_time\":{\"type\":\"number\",\"description\":\"[s]\"},\"offset_rol"
    "l\":{\"type\":\"number\",\"description\":\"[deg]\"}}}},\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"title\":\"Georeferencing Parameters\"}"
    ,
    /* example: */
    "{\"socs_to_body_matrix\":[[-0.269827776749716,-0.723017716139738,0.63595"
    "4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\""
    "body_coordinate_system_type\":\"NED\",\"trajectory_file\":{\"file_uuid\":\"93a"
    "03615-66c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"pofx\"},\"trajector"
    "y_offsets\":{\"version\":0,\"offset_east\":0.15,\"offset_yaw\":-0.45,\"offset_"
    "north\":0.07,\"offset_height\":-0.2,\"offset_pitch\":0.01,\"offset_time\":18."
    "007,\"offset_roll\":0.03}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"additionalProperties\":false,\"patternProperties\":{\"^-"
    "?[0-9]+$\":{\"type\":\"string\",\"description\":\"One field per item, field "
    "name is item id, field value is item name\"}},\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"title\":\"Item Names\",\"description\":\"Map of "
    "item names\"}"
    ,
    /* example: */
    "{\"-1\":\"Name of item with id -1\",\"2\":\"Name of item with id 2\",\"1\":\"Name"
    " of item with id 1\",\"47\":\"Name of item with id 47\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"additionalProperties\":false,\"patternProperties\":{\"^."
    "*$\":{\"type\":\"array\",\"description\":\"Each field of the object represents"
    " a feature and holds a list of license keys, where the field name is "
    "the feature name.\",\"items\":{\"type\":\"string\",\"description\":\"License key"
    " (example: '46AE032A - 39882AC4 - 9EC0A184 - 6F163D73')\"},\"minItems\":1"
    "}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Softwa"
    "re License Keys\",\"description\":\"License keys for software features\"}"
    ,
    /* example: */
    "{\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - 6F163D73\"],\"Full "
    "Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA - "
    "8D2ED557\"],\"MTA resolution\":[\"468E020A - 39A922E4 - B681A184 - "
    "673E3D72\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - 34EF7E7B\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Parameters for MTA processing\",\"proper"
    "ties\":{\"modulation_depth\":{\"type\":\"number\",\"description\":\"Depth of "
    "pulse position modulation in meter.\",\"minimum\":0},\"zone_count\":{\"type\""
    ":\"integer\",\"maximum\":255,\"description\":\"Maximum number of MTA zones.\","
    "\"minimum\":0},\"zone_width\":{\"type\":\"number\",\"description\":\"Width of a "
    "MTA zone in meter.\",\"minimum\":0}},\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"title\":\"MTA Settings\"}"
    ,
    /* example: */
    "{\"modulation_depth\":9.368514,\"zone_count\":23,\"zone_width\":149.896225}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"delta\",\"content\"],\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\",\"properties\":{\"content\":{\"type\":\"array\","
    "\"maxItems\":2000,\"description\":\"Correction value [m] to be added to the"
    " raw range\",\"items\":{\"type\":\"number\"},\"minItems\":1},\"delta\":{\"type\":\"n"
    "umber\",\"description\":\"Delta between table entries [m], first entry is "
    "at range = 0 m\"}},\"title\":\"Near Range Correction "
    "Table\",\"description\":\"Lookup table for range correction based on raw "
    "range\"}"
    ,
    /* example: */
    "{\"content\":[0.0],\"delta\":0.512}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigm"
    "a\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{"
    "\"amplitude_sigma\":{\"type\":\"array\",\"description\":\"Sigma amplitude [dB]\""
    ",\"items\":{\"type\":\"number\"}},\"range_sigma\":{\"type\":\"array\",\"description"
    "\":\"Sigma range [m]\",\"items\":{\"type\":\"number\"}},\"amplitude\":{\"type\":\"ar"
    "ray\",\"description\":\"Amplitude "
    "[dB]\",\"items\":{\"type\":\"number\"}}},\"title\":\"Noise "
    "Estimates\",\"description\":\"Standard deviation for range and amplitude "
    "as a function of amplitude\"}"
    ,
    /* example: */
    "{\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.4"
    "32,0.39,0.354],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.02"
    "4,0.021,0.018,0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7."
    "0,8.0,9.0,10.0]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"range_minimum\",\"range_maximum\",\"amplitud"
    "e_maximum\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"prope"
    "rties\":{\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum range "
    "[m]\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "amplitude [dB]\",\"minimum\":0},\"range_maximum\":{\"type\":\"number\",\"descrip"
    "tion\":\"Maximum range [m]\"}},\"title\":\"Notch "
    "Filter\",\"description\":\"Notch filter parameters for window glass "
    "echoes\"}"
    ,
    /* example: */
    "{\"range_minimum\":-0.5,\"amplitude_maximum\":18.0,\"range_maximum\":0.2}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"size\"],\"definitions\":{\"pixel_size\":{\"typ"
    "e\":\"array\",\"maxItems\":2,\"description\":\"Size of "
    "pixels.\",\"items\":{\"type\":\"number\",\"description\":\"Length of pixel edge "
    "[m].\",\"minimum\":0},\"minItems\":2}},\"properties\":{\"size\":{\"description\":"
    "\"Size of pixels in file coordinate system.\",\"$ref\":\"#/definitions/pixe"
    "l_size\"},\"size_llcs\":{\"description\":\"Size of pixels in a locally "
    "levelled cartesian coordinate system (xy). This is only used for "
    "pixels based on a map projection.\",\"$ref\":\"#/definitions/pixel_size\"}}"
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Pixel "
    "Information\",\"description\":\"Details about the pixels contained in the "
    "file\"}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395],\"size_llcs\":[0.5156575"
    "252891171,0.5130835356683303]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"plane_patch_file_one\",\"plane_patch_file_"
    "two\"],\"definitions\":{\"file_reference\":{\"type\":\"object\",\"required\":[\"fi"
    "le_uuid\",\"file_path\"],\"description\":\"Reference to a plane patch "
    "file\",\"properties\":{\"file_path\":{\"type\":\"string\",\"description\":\"Path "
    "of the plane patch file relative to the match "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC 4122)\"}}}},\"properties\":{\"plane_pat"
    "ch_file_two\":{\"description\":\"Reference to the plane patch file two\",\"$"
    "ref\":\"#/definitions/file_reference\"},\"plane_patch_file_one\":{\"descript"
    "ion\":\"Reference to the plane patch file one\",\"$ref\":\"#/definitions/fil"
    "e_reference\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"ti"
    "tle\":\"Plane Patch Matching\",\"description\":\"Details about the plane "
    "patch matching process\"}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d"
    "509-a64e-49ce-8b14-ff3130fbefa9\"},\"plane_patch_file_one\":{\"file_path\":"
    "\"Record009_Line001/191025_121410_Scanner_1.ptch\",\"file_uuid\":\"810f5d57"
    "-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Statistics about plane patches found "
    "by plane patch extractor\",\"properties\":{\"total_horizontal_area\":{\"type"
    "\":\"number\",\"description\":\"sum of all plane patch areas projected to "
    "horizontal plane "
    "[m\\u00b2]\"},\"total_area\":{\"type\":\"number\",\"description\":\"sum of all "
    "plane patch areas [m\\u00b2]\"}},\"$schema\":\"http://json-schema.org/draft"
    "-04/schema#\",\"title\":\"Plane Patch Statistics\"}"
    ,
    /* example: */
    "{\"total_horizontal_area\":13954.601,\"total_area\":14007.965}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"settings\",\"classes\"],\"definitions\":{\"met"
    "hod-1\":{\"type\":\"object\",\"required\":[\"plane_classification_method\",\"max"
    "imum_inclination_angle_horizontal\"],\"description\":\"Classification "
    "method 1\",\"properties\":{\"plane_classification_method\":{\"type\":\"integer"
    "\",\"maximum\":1,\"description\":\"method ID (=1)\",\"minimum\":1},\"maximum_inc"
    "lination_angle_horizontal\":{\"type\":\"number\",\"maximum\":360.0,\"descripti"
    "on\":\"maximum inclination angle of horizontal plane patches [deg]\",\"min"
    "imum\":-360.0}}},\"method-2\":{\"type\":\"object\",\"required\":[\"plane_classif"
    "ication_method\",\"sloping_plane_classes_minimum_angle\",\"sloping_plane_c"
    "lasses_maximum_angle\"],\"description\":\"Classification method 2\",\"proper"
    "ties\":{\"plane_classification_method\":{\"type\":\"integer\",\"maximum\":2,\"de"
    "scription\":\"method ID (=2)\",\"minimum\":2},\"sloping_plane_classes_maximu"
    "m_angle\":{\"type\":\"number\",\"maximum\":360.0,\"description\":\"maximum "
    "inclination angle of sloping plane patches [deg]\",\"minimum\":-360.0},\"s"
    "loping_plane_classes_minimum_angle\":{\"type\":\"number\",\"maximum\":360.0,\""
    "description\":\"minimum inclination angle of sloping plane patches [deg]"
    "\",\"minimum\":-360.0}}}},\"properties\":{\"settings\":{\"type\":\"object\",\"oneO"
    "f\":[{\"$ref\":\"#/definitions/method-1\"},{\"$ref\":\"#/definitions/method-2\""
    "}],\"description\":\"Classification settings, details see documentation "
    "of rdbplanes\"},\"classes\":{\"type\":\"object\",\"additionalProperties\":false"
    ",\"patternProperties\":{\"^[0-9]+$\":{\"type\":\"string\",\"description\":\"one "
    "field per class, field name is class number, field value is class "
    "name\"}},\"description\":\"Class definition table\"}},\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"title\":\"Plane Slope Class "
    "Info\",\"description\":\"Settings and classes for plane slope "
    "classification\"}"
    ,
    /* example: */
    "{\"settings\":{\"plane_classification_method\":2,\"sloping_plane_classes_ma"
    "ximum_angle\":70.0,\"sloping_plane_classes_minimum_angle\":10.0},\"classes"
    "\":{\"2\":\"sloping, pointing up and east\",\"11\":\"sloping, pointing down "
    "and south\",\"9\":\"vertical, pointing west\",\"7\":\"vertical, pointing "
    "south\",\"5\":\"sloping, pointing up and west\",\"13\":\"sloping, pointing "
    "down and west\",\"6\":\"vertical, pointing east\",\"14\":\"horizontal, "
    "pointing down\",\"8\":\"vertical, pointing north\",\"1\":\"horizontal, "
    "pointing up\",\"10\":\"sloping, pointing down and east\",\"12\":\"sloping, "
    "pointing down and north\",\"3\":\"sloping, pointing up and "
    "south\",\"4\":\"sloping, pointing up and north\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"additionalProperties\":false,\"patternProperties\":{\"^."
    "*$\":{\"type\":\"array\",\"description\":\"Each field of the object represents"
    " a point attribute group and holds a list of point attributes, where "
    "the field name is the group "
    "name.\",\"items\":{\"type\":\"string\",\"description\":\"Point attribute full "
    "name or name pattern (perl regular expression syntax)\"},\"minItems\":1}}"
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Point "
    "Attribute Groups\",\"description\":\"Grouping and sorting of point "
    "attributes for visualization purposes\"}"
    ,
    /* example: */
    "{\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl"
    ".phi\"],\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"ri"
    "egl.deviation\"],\"Time\":[\"riegl.timestamp\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about point cloud "
    "files\",\"properties\":{\"project\":{\"type\":\"string\",\"description\":\"Project"
    " name\"},\"field_of_application\":{\"type\":\"string\",\"description\":\"Field "
    "of application\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\","
    "\"BLS\",\"ILS\"]},\"comments\":{\"type\":\"string\",\"description\":\"Comments\"}},\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Point "
    "Cloud Information\"}"
    ,
    /* example: */
    "{\"project\":\"Campaign 4\",\"field_of_application\":\"ALS\",\"comments\":\"Line "
    "3\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"orientation\"],\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"properties\":{\"orientation\":{\"type\":\"object\""
    ",\"required\":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"ya"
    "w_accuracy\"],\"description\":\"Orientation values and orientation "
    "accuracies, measured with IMU or inclination sensors.\",\"properties\":{\""
    "pitch\":{\"type\":\"number\",\"maximum\":360,\"description\":\"Pitch angle about"
    " scanner Y-axis [deg]\",\"minimum\":-360},\"roll_accuracy\":{\"type\":\"number"
    "\",\"exclusiveMinimum\":true,\"description\":\"Roll angle accuracy [deg]\",\"m"
    "inimum\":0},\"roll\":{\"type\":\"number\",\"maximum\":360,\"description\":\"Roll "
    "angle about scanner X-axis [deg]\",\"minimum\":-360},\"pitch_accuracy\":{\"t"
    "ype\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Pitch angle "
    "accuracy [deg]\",\"minimum\":0},\"yaw\":{\"type\":\"number\",\"maximum\":360,\"des"
    "cription\":\"Yaw angle about scanner Z-axis [deg]\",\"minimum\":-360},\"yaw_"
    "accuracy\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Yaw "
    "angle accuracy [deg]\",\"minimum\":0}}},\"position\":{\"type\":\"object\",\"requ"
    "ired\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\"horizontal_accura"
    "cy\",\"vertical_accuracy\",\"crs\"],\"description\":\"Position coordinates and"
    " position accuracy values as measured by GNSS in the specified "
    "Coordinate Reference System (CRS)\",\"properties\":{\"coordinate_3\":{\"type"
    "\":\"number\",\"description\":\"Coordinate 3 as defined by axis 3 of the "
    "specified CRS (e.g., Z, Altitude)\"},\"vertical_accuracy\":{\"type\":\"numbe"
    "r\",\"exclusiveMinimum\":true,\"description\":\"Vertical accuracy [m]\",\"mini"
    "mum\":0},\"horizontal_accuracy\":{\"type\":\"number\",\"exclusiveMinimum\":true"
    ",\"description\":\"Horizontal accuracy [m]\",\"minimum\":0},\"coordinate_1\":{"
    "\"type\":\"number\",\"description\":\"Coordinate 1 as defined by axis 1 of "
    "the specified CRS (e.g., X, "
    "Latitude)\"},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coordinate "
    "2 as defined by axis 2 of the specified CRS (e.g., Y, Longitude)\"},\"cr"
    "s\":{\"type\":\"object\",\"required\":[\"epsg\"],\"description\":\"Global "
    "Coordinate Reference "
    "System\",\"properties\":{\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG "
    "code\",\"minimum\":0},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known "
    "Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan"
    "dards/wkt-crs)\"}}}}},\"barometric_height_amsl\":{\"type\":\"number\",\"descri"
    "ption\":\"Altitude determined based on the atmospheric pressure "
    "according to the standard atmosphere laws [m].\"}},\"title\":\"Pose "
    "Estimation\",\"description\":\"Estimated position and orientation "
    "information as measured by GNSS, IMU or inclination sensors\"}"
    ,
    /* example: */
    "{\"orientation\":{\"pitch\":1.509153024827064,\"roll_accuracy\":0.0094337839"
    "36875745,\"roll\":3.14743073066123,\"pitch_accuracy\":0.009433783936875745"
    ",\"yaw\":101.87293630292045,\"yaw_accuracy\":1.0094337839368757},\"position"
    "\":{\"coordinate_3\":362.7124938964844,\"vertical_accuracy\":1.331499934196"
    "4722,\"horizontal_accuracy\":0.810699999332428,\"coordinate_1\":48.6557994"
    "73,\"coordinate_2\":15.645033406,\"crs\":{\"epsg\":4979,\"wkt\":\"GEOGCS[\\\"WGS8"
    "4 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.25"
    "7223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PR"
    "IMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UN"
    "IT[\\\"Degree\\\",0.01745329251994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXI"
    "S[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"49"
    "79\\\"]]\"}},\"barometric_height_amsl\":386.7457796227932}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"gyroscope\",\"accelerometer\",\"magnetic_fie"
    "ld_sensor\"],\"definitions\":{\"vector\":{\"type\":\"array\",\"maxItems\":3,\"item"
    "s\":{\"type\":\"number\",\"description\":\"Index 0=X, 1=Y, 2=Z component\"},\"mi"
    "nItems\":3}},\"properties\":{\"magnetic_field_sensor\":{\"type\":\"object\",\"re"
    "quired\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_"
    "nonlinearity\"],\"description\":\"Magnetic Field Sensor details\",\"properti"
    "es\":{\"unit\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Un"
    "it of raw data and calibration values, 1 LSB in "
    "nT\",\"minimum\":0},\"relative_nonlinearity\":{\"description\":\"Relative "
    "nonlinearity, dimensionless\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{"
    "\"description\":\"Sensitive Y axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"fixed\":{\"description\":\"Distortion "
    "of magnetic field caused by non-rotating scanner "
    "part\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to"
    " be subtracted from raw measurement values\",\"$ref\":\"#/definitions/vect"
    "or\"},\"x_axis\":{\"description\":\"Sensitive X axis of sensor at frame "
    "angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}}},\""
    "accelerometer\":{\"type\":\"object\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\""
    "z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"description\":\"Acce"
    "lerometer details\",\"properties\":{\"unit\":{\"type\":\"number\",\"exclusiveMin"
    "imum\":true,\"description\":\"Unit of raw data and calibration values, 1 "
    "LSB in 9.81 m/s\\u00b2\",\"minimum\":0},\"relative_nonlinearity\":{\"descript"
    "ion\":\"Relative nonlinearity, dimensionless\",\"$ref\":\"#/definitions/vect"
    "or\"},\"y_axis\":{\"description\":\"Sensitive Y axis of sensor at frame "
    "angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "},\"x_axis\":{\"description\":\"Sensitive X axis of sensor at frame angle ="
    " 0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive "
    "Z axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"origin\":{\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}}"
    "},\"gyroscope\":{\"type\":\"object\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z"
    "_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"description\":\"Gyros"
    "cope details\",\"properties\":{\"unit\":{\"type\":\"number\",\"exclusiveMinimum\""
    ":true,\"description\":\"Unit of raw data and calibration values, 1 LSB in"
    " rad/s\",\"minimum\":0},\"relative_nonlinearity\":{\"description\":\"Relative "
    "nonlinearity, dimensionless\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{"
    "\"description\":\"Sensitive Y axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "},\"x_axis\":{\"description\":\"Sensitive X axis of sensor at frame angle ="
    " 0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive "
    "Z axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"origin\":{\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}}"
    "}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Pose "
    "Sensors\",\"description\":\"Details on position and orientation sensors\"}"
    ,
    /* example: */
    "{\"magnetic_field_sensor\":{\"unit\":91.74311828613281,\"relative_nonlinear"
    "ity\":[0.0,0.0,0.0],\"y_axis\":[0.00027888521435670555,-0.011427424848079"
    "681,-5.204829722060822e-05],\"fixed\":[-1576.010498046875,1596.081787109"
    "375,0.0],\"offset\":[-23812.052734375,5606.57666015625,2493.28125],\"x_ax"
    "is\":[-0.011162743903696537,-2.315962774446234e-05,0.000168188445968553"
    "42],\"z_axis\":[0.00041987866279669106,7.876977906562388e-05,0.011407104"
    "320824146]},\"accelerometer\":{\"unit\":6.666666740784422e-05,\"relative_no"
    "nlinearity\":[0.0,0.0,0.0],\"y_axis\":[-7.027288913726807,-44.12333679199"
    "219,14952.3701171875],\"offset\":[-733.3636474609375,58.969032287597656,"
    "1060.2550048828125],\"x_axis\":[-15008.123046875,56.956390380859375,-60."
    "5175666809082],\"z_axis\":[1.639882206916809,15166.744140625,-116.997428"
    "89404297],\"origin\":[0.026900000870227814,-0.03999999910593033,-0.08950"
    "000256299973]},\"gyroscope\":{\"unit\":0.00014544410805683583,\"relative_no"
    "nlinearity\":[2.888176311444113e-07,1.06274164579645e-07,-1.71862950806"
    "34935e-39],\"y_axis\":[-0.440765917301178,-0.7897399663925171,119.589477"
    "5390625],\"offset\":[-50.92609786987305,146.15643310546875,62.4327278137"
    "207],\"x_axis\":[-121.195556640625,0.8219714164733887,0.2313031703233719"
    "],\"z_axis\":[0.555869996547699,119.22135162353516,0.467585027217865],\"o"
    "rigin\":[0.026900000870227814,-0.03999999910593033,-0.08950000256299973"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"]"
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"pu"
    "lse_interval\":{\"type\":\"array\",\"description\":\"Explicit table of the "
    "pulse position modulation used for MTA resolution. Table gives times "
    "between successive laser pulses in seconds.\",\"items\":{\"type\":\"number\","
    "\"minimum\":0}},\"phase_step\":{\"type\":\"integer\",\"maximum\":255,\"descriptio"
    "n\":\"Step width in phase of modulation code from line to line\",\"minimum"
    "\":0},\"length\":{\"type\":\"integer\",\"maximum\":255,\"description\":\"Length of"
    " code\",\"minimum\":0},\"code_phase_mode\":{\"type\":\"integer\",\"maximum\":255,"
    "\"description\":\"0: no synchronization, 1: toggle between 2 phases, 2: "
    "increment with phase_increment\",\"minimum\":0},\"num_mod_ampl\":{\"type\":\"i"
    "nteger\",\"maximum\":255,\"description\":\"Number of different modulation "
    "amplitudes (2: binary modulation)\",\"minimum\":0}},\"title\":\"Pulse "
    "Position Modulation\",\"description\":\"Laser pulse position modulation "
    "used for MTA resolution\"}"
    ,
    /* example: */
    "{\"pulse_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06"
    ",2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.82"
    "1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e"
    "-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2"
    ".759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.8218"
    "75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-0"
    "6],\"phase_step\":5,\"length\":31,\"code_phase_mode\":2,\"num_mod_ampl\":2}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],"
    "\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"max"
    "imum\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"},\"average\":{\"type\":\"number\",\"description\":\"Average "
    "value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"}},\"title\":\"Range Statistics\",\"description\":\"Statistics about "
    "target distance wrt. SOCS origin\"}"
    ,
    /* example: */
    "{\"maximum\":574.35,\"average\":15.49738,\"std_dev\":24.349,\"minimum\":0.919}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"fp\":{\"type\":\"object\",\"required\":[\"s\","
    "\"w\"],\"description\":\"Fingerprint values\",\"properties\":{\"s\":{\"type\":\"arr"
    "ay\",\"maxItems\":256,\"items\":{\"type\":\"array\",\"maxItems\":4096,\"items\":{\"t"
    "ype\":\"number\"},\"minItems\":1},\"minItems\":1},\"w\":{\"type\":\"array\",\"maxIte"
    "ms\":256,\"items\":{\"type\":\"array\",\"maxItems\":5,\"items\":{\"type\":\"number\"}"
    ",\"minItems\":5},\"minItems\":1}}},\"fp_table\":{\"type\":\"object\",\"required\":"
    "[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"desription\":\"scanner internal "
    "data\",\"properties\":{\"tc\":{\"type\":\"integer\",\"description\":\"table data "
    "type "
    "code\",\"max\":255,\"min\":0},\"ch\":{\"type\":\"integer\",\"description\":\"channel"
    " number\",\"max\":255,\"min\":0},\"nx\":{\"type\":\"integer\",\"description\":\"numb"
    "er of x entries\",\"max\":2048,\"min\":1},\"tv\":{\"type\":\"array\",\"maxItems\":2"
    "048,\"items\":{\"oneOf\":[{\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":\"n"
    "umber\"}]},\"minItems\":1},\"ny\":{\"type\":\"integer\",\"description\":\"number "
    "of y entries\",\"max\":2048,\"min\":1}}},\"fp_table_row\":{\"type\":\"array\",\"ma"
    "xItems\":2048,\"items\":{\"type\":\"number\"},\"minItems\":1}},\"properties\":{\"e"
    "x\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' "
    "instead\"},\"mw\":{\"type\":\"number\",\"description\":\"Maximum weight\",\"exclus"
    "iveMinimum\":true,\"maximum\":4095,\"minimum\":0},\"sr\":{\"type\":\"number\",\"ex"
    "clusiveMinimum\":true,\"description\":\"Sample rate "
    "[Hz]\",\"minimum\":0},\"a\":{\"type\":\"array\",\"description\":\"Amplitude [dB]\","
    "\"maxItems\":256,\"items\":{\"type\":\"number\"},\"minItems\":1},\"nt\":{\"type\":\"i"
    "nteger\",\"description\":\"Number of traces\",\"maximum\":255,\"minimum\":0},\"n"
    "s\":{\"type\":\"integer\",\"description\":\"Number of samples\",\"maximum\":4095,"
    "\"minimum\":0},\"tbl\":{\"type\":\"array\",\"description\":\"various internal dat"
    "a\",\"items\":{\"$ref\":\"#/definitions/fp_table\"},\"minItems\":1},\"t\":{\"type\""
    ":\"object\",\"additionalProperties\":false,\"patternProperties\":{\"^[0-9]+$\""
    ":{\"description\":\"one field per channel, field name is channel index\",\""
    "$ref\":\"#/definitions/fp\"}}},\"si\":{\"type\":\"number\",\"description\":\"Start"
    " index (hw_start)\",\"maximum\":255,\"minimum\":0}},\"$schema\":\"http://json-"
    "schema.org/draft-04/schema#\",\"title\":\"Receiver "
    "Internals\",\"description\":\"Receiver Internals\"}"
    ,
    /* example: */
    "{\"mw\":31,\"sr\":7959997000.0,\"a\":[-1.55],\"nt\":128,\"ns\":400,\"tbl\":[{\"tc\":"
    "1,\"ch\":0,\"nx\":5,\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],\"ny\":2}],\"t\":"
    "{\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[78,86,126"
    ",134,31]]},\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],"
    "[78,86,126,134,31]]}},\"si\":48}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"delta\",\"content\"],\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\",\"properties\":{\"content\":{\"type\":\"array\","
    "\"maxItems\":2000,\"description\":\"Correction value [dB] to be added to "
    "the amplitude\",\"items\":{\"type\":\"number\"},\"minItems\":1},\"delta\":{\"type\""
    ":\"number\",\"description\":\"Delta between table entries [m], first entry "
    "is at range = 0 m\"}},\"title\":\"Reflectance Calculation "
    "Table\",\"description\":\"Lookup table for reflectance calculation based "
    "on amplitude and range\"}"
    ,
    /* example: */
    "{\"content\":[-33.01],\"delta\":0.150918}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"ranges_m\",\"line_angles_deg\",\"reflectance"
    "_correction_db\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "properties\":{\"line_angles_deg\":{\"type\":\"array\",\"description\":\"Angle [d"
    "eg]\",\"items\":{\"type\":\"number\"}},\"ranges_m\":{\"type\":\"array\",\"descriptio"
    "n\":\"Range [m]\",\"items\":{\"type\":\"number\"}},\"reflectance_correction_db\":"
    "{\"type\":\"array\",\"description\":\"Near range reflectance correction in dB"
    " as a function of range over "
    "angle\",\"items\":{\"type\":\"array\",\"description\":\"rows (each array "
    "corresponds to a "
    "range)\",\"items\":{\"type\":\"number\",\"description\":\"columns (each value "
    "corresponds to an angle)\"}}}},\"title\":\"Near-range reflectance "
    "correction\",\"description\":\"Range-dependent and scan-angle-dependent "
    "correction of reflectance reading\"}"
    ,
    /* example: */
    "{\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"ranges_m"
    "\":[0.0,1.0,2.0,3.0],\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,"
    "0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0."
    "8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,"
    "0.1,0.05,0.01]]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"program\":{\"type\":\"object\",\"required\":[\"name\"],\"descri"
    "ption\":\"Measurement "
    "program\",\"properties\":{\"name\":{\"type\":\"string\",\"description\":\"Name of "
    "measurement program\"},\"laser_prr\":{\"type\":\"number\",\"exclusiveMinimum\":"
    "false,\"description\":\"Laser Pulse Repetition Rate "
    "[Hz]\",\"minimum\":0}}}},\"description\":\"Scan pattern description\",\"proper"
    "ties\":{\"segments\":{\"type\":\"object\",\"required\":[\"list\"],\"description\":\""
    "Segmented Line Scan Pattern\",\"properties\":{\"program\":{\"$ref\":\"#/defini"
    "tions/program\"},\"list\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"requi"
    "red\":[\"start\",\"stop\",\"increment\"],\"description\":\"Line Scan Segment\",\"p"
    "roperties\":{\"start\":{\"type\":\"number\",\"maximum\":360.0,\"description\":\"St"
    "art angle in SOCS [deg]\",\"minimum\":0.0},\"stop\":{\"type\":\"number\",\"maxim"
    "um\":720.0,\"description\":\"Stop angle in SOCS [deg]\",\"minimum\":0.0},\"inc"
    "rement\":{\"type\":\"number\",\"maximum\":90.0,\"description\":\"Increment of "
    "angle in SOCS [deg]\",\"minimum\":0.0}}}}}},\"line\":{\"type\":\"object\",\"requ"
    "ired\":[\"start\",\"stop\",\"increment\"],\"description\":\"Line Scan Pattern\",\""
    "properties\":{\"start\":{\"type\":\"number\",\"maximum\":360.0,\"description\":\"S"
    "tart angle in SOCS [deg]\",\"minimum\":0.0},\"program\":{\"$ref\":\"#/definiti"
    "ons/program\"},\"stop\":{\"type\":\"number\",\"maximum\":720.0,\"description\":\"S"
    "top angle in SOCS [deg]\",\"minimum\":0.0},\"increment\":{\"type\":\"number\",\""
    "maximum\":90.0,\"description\":\"Increment of angle in SOCS [deg]\",\"minimu"
    "m\":0.0}}},\"rectangular\":{\"type\":\"object\",\"required\":[\"phi_start\",\"phi_"
    "stop\",\"phi_increment\",\"theta_start\",\"theta_stop\",\"theta_increment\"],\"d"
    "escription\":\"Rectangular Field Of View Scan Pattern\",\"properties\":{\"ph"
    "i_stop\":{\"type\":\"number\",\"maximum\":720.0,\"description\":\"Stop phi angle"
    " in SOCS [deg]\",\"minimum\":0.0},\"program\":{\"$ref\":\"#/definitions/progra"
    "m\"},\"phi_increment\":{\"type\":\"number\",\"maximum\":90.0,\"description\":\"Inc"
    "rement of phi angle in SOCS [deg]\",\"minimum\":0.0},\"phi_start\":{\"type\":"
    "\"number\",\"maximum\":360.0,\"description\":\"Start phi angle in SOCS [deg]\""
    ",\"minimum\":0.0},\"theta_start\":{\"type\":\"number\",\"maximum\":180.0,\"descri"
    "ption\":\"Start theta angle in SOCS [deg]\",\"minimum\":0.0},\"theta_stop\":{"
    "\"type\":\"number\",\"maximum\":180.0,\"description\":\"Stop theta angle in "
    "SOCS [deg]\",\"minimum\":0.0},\"theta_increment\":{\"type\":\"number\",\"maximum"
    "\":90.0,\"description\":\"Increment of theta angle in SOCS [deg]\",\"minimum"
    "\":0.0}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":"
    "\"Scan Pattern\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"phi_stop\":270.0,\"program\":{\"name\":\"High Speed\",\"laser"
    "_prr\":100000.0},\"phi_increment\":0.04,\"phi_start\":45.0,\"theta_start\":30"
    ".0,\"theta_stop\":130.0,\"theta_increment\":0.04}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about laser shot files\",\"prope"
    "rties\":{\"shot_file\":{\"type\":\"object\",\"required\":[\"file_extension\"],\"pr"
    "operties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading dot\"}}}},\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"title\":\"Shot Information\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"activated\",\"filters\"],\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"properties\":{\"filters\":{\"type\":\"arr"
    "ay\",\"description\":\"List of point filters\",\"items\":{\"type\":\"object\",\"re"
    "quired\":[\"activated\",\"title\",\"description\",\"filter\"],\"description\":\"Po"
    "int filter "
    "definition\",\"properties\":{\"filter\":{\"type\":\"string\",\"description\":\"The"
    " RDB filter string to apply (e.g. when reading points or index), "
    "details see documentation of function "
    "select()\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true')"
    " or ignore ('false') this "
    "filter\"},\"title\":{\"type\":\"string\",\"description\":\"A short filter title "
    "(e.g. for display in a selection "
    "list)\"}}}},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true')"
    " or ignore ('false') all filters\"}},\"title\":\"Stored "
    "filters\",\"description\":\"Point filters applied in addition to the "
    "application-defined filters\"}"
    ,
    /* example: */
    "{\"filters\":[{\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"description\":\"Ignore points with uncertain MTA zone "
    "assignment\",\"activated\":false,\"title\":\"Ignore uncertain points from "
    "MTA resolution\"},{\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"description\":\"Ignore points with an echo signal amplitude below "
    "the dynamic trigger\",\"activated\":false,\"title\":\"Ignore points below "
    "dynamic trigger level\"},{\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are outside the outer AABB in "
    "BOCS\",\"activated\":false,\"title\":\"Ignore points outside outer "
    "AABB\"},{\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are inside the inner AABB in "
    "BOCS\",\"activated\":false,\"title\":\"Ignore points inside inner "
    "AABB\"}],\"activated\":true}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"$class\",\"version\",\"author\",\"timestamp\",\""
    "system\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properti"
    "es\":{\"version\":{\"type\":\"string\",\"description\":\"Document format "
    "version\"},\"$class\":{\"type\":\"string\",\"description\":\"Object class name\","
    "\"enum\":[\"Document\"]},\"timestamp\":{\"type\":\"string\",\"description\":\"Date "
    "and time of creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"system\":{\"typ"
    "e\":\"object\",\"description\":\"The actual system description, details see "
    "documentation of RIEGL System "
    "Description\"},\"author\":{\"type\":\"string\",\"description\":\"Name of the "
    "author that created the document\"}},\"title\":\"System "
    "Description\",\"description\":\"Details of major system components like "
    "lidar sensors, cameras and navigation devices\"}"
    ,
    /* example: */
    "{\"version\":\"1.2.1\",\"$class\":\"Document\",\"timestamp\":\"2022-09-30T11:56:2"
    "6+00:00\",\"system\":{\"details\":\"see documentation of RIEGL System "
    "Description\"},\"author\":\"RIEGL LMS GmbH, Austria\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"conversion_table\":{\"type\":\"object\",\"r"
    "equired\":[\"value\",\"temperature\"],\"properties\":{\"value\":{\"type\":\"array\""
    ",\"description\":\"LSB [1]\",\"items\":{\"type\":\"number\"}},\"temperature\":{\"ty"
    "pe\":\"array\",\"description\":\"Temperature [\\u00b0C]\",\"items\":{\"type\":\"num"
    "ber\"}}}}},\"properties\":{\"InGaAs_Si_Difference\":{\"description\":\"Convers"
    "ion table for InGaAs - Si difference\",\"$ref\":\"#/definitions/conversion"
    "_table\"},\"Si\":{\"description\":\"Conversion table for Si channel\",\"$ref\":"
    "\"#/definitions/conversion_table\"},\"InGaAs\":{\"description\":\"Conversion "
    "table for InGaAs channel\",\"$ref\":\"#/definitions/conversion_table\"}},\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Temperature"
    " Calculation Table\",\"description\":\"Conversion of background radiation "
    "raw values to temperatures in \\u00b0C\"}"
    ,
    /* example: */
    "{\"InGaAs_Si_Difference\":{\"value\":[1000.0,1100.090029602954,1200.044251"
    "83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13"
    "27555162209,1700.0869777520065,1800.0411999877924],\"temperature\":[1749"
    ".977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109"
    "2,1622.3944822534868]},\"Si\":{\"value\":[0.0,64.00097659230323,128.001953"
    "1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005"
    "8595538194,448.0068361461226,512.0078127384259],\"temperature\":[546.300"
    "048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60"
    "4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0"
    "002936624203]},\"InGaAs\":{\"value\":[0.0,64.00097659230323,128.0019531846"
    "065,192.0029297769097,256.0039063692129,320.00488296151616,384.0058595"
    "538194,448.0068361461226,512.0078127384259],\"temperature\":[307.2219672"
    "2535614,309.1153478247277,311.1188086915047,313.10025350480055,315.213"
    "7946389828,317.2172555057597,319.2207163725366,321.2021611858325,323.3"
    "157023200148]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"epoch\",\"source\"],\"$schema\":\"http://json-"
    "schema.org/draft-04/schema#\",\"properties\":{\"epoch\":{\"type\":\"string\",\"d"
    "escription\":\"Date and time of timestamp '0' as proposed by RFC 3339 "
    "(e.g. 2015-10-27T00:00:00+01:00).\"},\"source\":{\"type\":\"string\",\"descrip"
    "tion\":\"Timestamp source\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"]},\"system\":{\"t"
    "ype\":\"string\",\"description\":\"Time system (time "
    "standard)\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"]}},\"title\":\"Time "
    "Base\",\"description\":\"Base of timestamps (epoch)\"}"
    ,
    /* example: */
    "{\"epoch\":\"2015-10-27T00:00:00+00:00\",\"source\":\"GNSS\",\"system\":\"UTC\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"time_interval\",\"navigation_frame\"],\"$sch"
    "ema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"location"
    "\":{\"type\":\"string\",\"description\":\"Project location, e.g. "
    "city/state/country\"},\"project\":{\"type\":\"string\",\"description\":\"Project"
    " name\"},\"navigation_frame\":{\"type\":\"string\",\"description\":\"Navigation "
    "frame (NED: North-East-Down, ENU: East-North-Up)\",\"enum\":[\"unknown\",\"N"
    "ED\",\"ENU\"]},\"settings\":{\"type\":\"string\",\"description\":\"Settings used "
    "to calculate the trajectory (descriptive text)\"},\"time_interval\":{\"typ"
    "e\":\"object\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"desc"
    "ription\":\"Time interval statistics\",\"properties\":{\"maximum\":{\"type\":\"n"
    "umber\",\"description\":\"Maximum time interval "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard deviation of "
    "intervals [s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time"
    " interval [s]\"}}},\"device\":{\"type\":\"string\",\"description\":\"Navigation "
    "device, e.g. name/type/serial\"},\"field_of_application\":{\"type\":\"string"
    "\",\"description\":\"Field of application\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\""
    "KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"]},\"company\":{\"type\":\"string\",\"descr"
    "iption\":\"Company "
    "name\"},\"software\":{\"type\":\"string\",\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the file)\"}},\"title\":\"Trajectory "
    "Information\",\"description\":\"Details about position+orientation files\"}"
    ,
    /* example: */
    "{\"location\":\"Horn\",\"project\":\"Campaign 3\",\"navigation_frame\":\"NED\",\"se"
    "ttings\":\"default\",\"time_interval\":{\"maximum\":0.005004883,\"average\":0.0"
    "0500053,\"std_dev\":5.51e-07,\"minimum\":0.00500032},\"device\":\"IMU Model "
    "12/1, Serial# 12345\",\"field_of_application\":\"MLS\",\"company\":\"RIEGL "
    "LMS\",\"software\":\"Navigation Software XYZ\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"ttip_version\",\"num_channel\",\"ext_channel"
    "\",\"ext_signal\",\"ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\""
    "dmi_min_time\",\"dmi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_des"
    "cr\",\"input_descr\",\"output_usage\",\"input_usage\",\"out_polarity\",\"out_dur"
    "ation\",\"out_interval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_m"
    "in_duration\",\"in_max_duration\",\"in_max_delay\"],\"$schema\":\"http://json-"
    "schema.org/draft-04/schema#\",\"properties\":{\"num_channel\":{\"type\":\"inte"
    "ger\",\"description\":\"number of input/output channels\",\"minimum\":0},\"dmi"
    "_min_time\":{\"type\":\"integer\",\"description\":\"dmi, minimum time interval"
    " between trigger events [0.1 msec]\",\"minimum\":0},\"ext_delay\":{\"type\":\""
    "integer\",\"description\":\"external trigger, time delay [0.1 "
    "msec]\",\"minimum\":0},\"output_usage\":{\"type\":\"integer\",\"description\":\"0 "
    ".. no output, 1 .. output derived from internal clock, 2 .. output "
    "derived from dmi, 3 .. output derived from external signal, 4 .. "
    "output static low, 5 .. output static high\",\"minimum\":0},\"out_interval"
    "\":{\"type\":\"integer\",\"description\":\"output pulse interval [0.1 msec]\",\""
    "minimum\":0},\"in_min_duration\":{\"type\":\"integer\",\"description\":\"input "
    "signals with smaller pulse durations are ignored [0.1 "
    "msec]\",\"minimum\":0},\"in_polarity\":{\"type\":\"integer\",\"description\":\"0 "
    ".. positive edge, 1 .. negative edge\",\"minimum\":0},\"ext_subdivider\":{\""
    "type\":\"integer\",\"description\":\"reduces the frequency, default "
    "1\",\"minimum\":0},\"channel\":{\"type\":\"integer\",\"description\":\"ID of "
    "input/output channel\",\"minimum\":0},\"out_duration\":{\"type\":\"integer\",\"d"
    "escription\":\"output pulse duration [0.1 msec]\",\"minimum\":0},\"out_num_p"
    "ulses\":{\"type\":\"integer\",\"description\":\"number of output pulses to be "
    "generated, 0 .. infinite\",\"minimum\":0},\"ttip_version\":{\"type\":\"integer"
    "\",\"description\":\"following main.sub.ss.sss\",\"minimum\":0},\"dmi_dist_per"
    "_tick\":{\"type\":\"number\",\"description\":\"dmi, distance per tick, just "
    "informative "
    "[m]\"},\"output_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"in_max_duration\":{\"type\":\"integer\",\"description\":\"stops "
    "measurement of pulse duration of input signal [0.1 msec]\",\"minimum\":0}"
    ",\"in_max_delay\":{\"type\":\"integer\",\"description\":\"maximum delay to "
    "output pulse before fake event is generated [0.1 msec], zero indicates"
    " that no fake events are generated\",\"minimum\":0},\"dmi_max_time\":{\"type"
    "\":\"integer\",\"description\":\"dmi, maximum time interval between trigger "
    "events [0.1 "
    "msec]\",\"minimum\":0},\"ext_signal\":{\"type\":\"integer\",\"description\":\"0 .."
    " use input signal, 1 .. use output signal of "
    "channel\",\"minimum\":0},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi,"
    " increment in ticks\"},\"input_usage\":{\"type\":\"integer\",\"description\":\"0"
    " .. deactivated, 1 .. just detecting and timestamping\",\"minimum\":0},\"e"
    "xt_channel\":{\"type\":\"integer\",\"description\":\"ID of channel used as "
    "external trigger input, 32 indicates "
    "none\",\"minimum\":0},\"out_polarity\":{\"type\":\"integer\",\"description\":\"0 "
    ".. positive edge, 1 .. negative edge\",\"minimum\":0},\"input_descr\":{\"typ"
    "e\":\"string\",\"description\":\"descriptive "
    "string\"},\"ext_bitmask\":{\"type\":\"integer\",\"description\":\"defines which "
    "of the internal pulse generators are to be started\",\"minimum\":0},\"out_"
    "delay\":{\"type\":\"integer\",\"description\":\"output pulse initial delay "
    "after start [0.1 msec]\",\"minimum\":0}},\"title\":\"TTIP "
    "Configuration\",\"description\":\"Trigger-Timestamping-Unit/IP "
    "configuration\"}"
    ,
    /* example: */
    "{\"num_channel\":9,\"dmi_min_time\":0,\"ext_delay\":0,\"output_usage\":1,\"out_"
    "interval\":10000,\"in_min_duration\":0,\"in_polarity\":0,\"ext_subdivider\":1"
    ",\"channel\":0,\"out_duration\":300,\"out_num_pulses\":1,\"ttip_version\":1,\"d"
    "mi_dist_per_tick\":0.0,\"output_descr\":\"Port 1 - Trigger\",\"in_max_durati"
    "on\":10000,\"in_max_delay\":9990,\"dmi_max_time\":0,\"ext_signal\":0,\"dmi_inc"
    "r\":0,\"input_usage\":1,\"ext_channel\":32,\"out_polarity\":0,\"input_descr\":\""
    "Port 1 - Exposure\",\"ext_bitmask\":0,\"out_delay\":0}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about vertex file\",\"properties"
    "\":{\"vertex_file\":{\"type\":\"object\",\"required\":[\"file_extension\"],\"prope"
    "rties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally"
    " Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex file "
    "extension, without the leading dot\"}}}},\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"title\":\"Vertex Information\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"voxel_size_cubic\":{\"type\":\"number\",\"$"
    "ref\":\"#/definitions/edge_length\"},\"shape_thresholds\":{\"type\":\"object\","
    "\"required\":[\"plane\",\"line\"],\"description\":\"Thresholds used to compute "
    "the voxel's shape_id value.\",\"properties\":{\"plane\":{\"type\":\"number\",\"e"
    "xclusiveMaximum\":true,\"exclusiveMinimum\":true,\"minimum\":0,\"description"
    "\":\"If the smallest eigenvalue is smaller than the median eigenvalue * "
    "plane_threshold, the voxel is considered a plane.\",\"maximum\":1},\"line\""
    ":{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"If the "
    "biggest eigenvalue is bigger than the median eigenvalue * "
    "line_threshold, the voxel is considered a line.\",\"minimum\":1}}},\"voxel"
    "_size\":{\"type\":\"array\",\"maxItems\":3,\"description\":\"Size of voxels.\",\"i"
    "tems\":{\"$ref\":\"#/definitions/edge_length\"},\"minItems\":3},\"voxel_origin"
    "_point\":{\"type\":\"array\",\"maxItems\":3,\"description\":\"Origin point for "
    "all voxel indices in voxel CRS.\",\"items\":{\"type\":\"number\"},\"minItems\":"
    "3},\"voxel_type\":{\"default\":\"centroid\",\"description\":\"Whether a point "
    "in a voxel represents its center or its centroid. If type is "
    "<tt>index</tt> there is no point but only an integer voxel index.\",\"en"
    "um\":[\"center\",\"centroid\",\"index\"]},\"edge_length\":{\"type\":\"number\",\"exc"
    "lusiveMinimum\":true,\"description\":\"Length of voxel edge [m].\",\"minimum"
    "\":0},\"voxel_origin_enum\":{\"default\":\"corner\",\"description\":\"Defines "
    "whether the voxel's center or a corner is placed on CRS origin <tt>(0/"
    "0/0)</tt>.\",\"enum\":[\"center\",\"corner\"]}},\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"title\":\"Voxel "
    "Information\",\"description\":\"Details about the voxels contained in the "
    "file\",\"oneOf\":[{\"required\":[\"size\",\"voxel_origin\",\"voxel_type\"],\"addit"
    "ionalProperties\":false,\"properties\":{\"size\":{\"oneOf\":[{\"$ref\":\"#/defin"
    "itions/voxel_size\"},{\"$ref\":\"#/definitions/voxel_size_cubic\"}],\"descri"
    "ption\":\"Size of voxels in file coordinate system.\"},\"shape_thresholds\""
    ":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel_origin\":{\"$ref\":\"#/d"
    "efinitions/voxel_origin_enum\"},\"voxel_type\":{\"$ref\":\"#/definitions/vox"
    "el_type\"}}},{\"required\":[\"reference_point\",\"size_llcs\",\"size\",\"voxel_o"
    "rigin\",\"voxel_type\"],\"additionalProperties\":false,\"properties\":{\"size\""
    ":{\"description\":\"Size of voxels in file coordinate system.\",\"$ref\":\"#/"
    "definitions/voxel_size\"},\"shape_thresholds\":{\"$ref\":\"#/definitions/sha"
    "pe_thresholds\"},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"refe"
    "rence_point\":{\"type\":\"array\",\"maxItems\":2,\"description\":\"Point in "
    "WGS84 geodetic decimal degree (EPSG:4326) that was used to compute the"
    " projection distortion parameters. The coefficient order is latitude, "
    "longitude. Only voxels with corresponding geo_tag, voxel_size and "
    "reference_point can be reliably processed together. This entry is "
    "available for voxel files in projected CRS only.\",\"items\":{\"type\":\"num"
    "ber\",\"maximum\":180,\"minimum\":-180},\"minItems\":2},\"voxel_origin\":{\"oneO"
    "f\":[{\"$ref\":\"#/definitions/voxel_origin_enum\"},{\"description\":\"The "
    "base point of the voxel grid. Used together with <tt>voxel_size</tt> "
    "and <tt>voxel_index</tt> to compute actual point coordinates.\",\"$ref\":"
    "\"#/definitions/voxel_origin_point\"}]},\"size_llcs\":{\"description\":\"Size"
    " of voxels in a locally levelled cartesian coordinate system (xyz). "
    "This is only used for voxels based on a map "
    "projection.\",\"$ref\":\"#/definitions/voxel_size\"}}}]}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395,0.5143705304787237],\"sh"
    "ape_thresholds\":{\"line\":6,\"plane\":0.16},\"voxel_type\":\"centroid\",\"refer"
    "ence_point\":[48,16],\"voxel_origin\":\"corner\",\"size_llcs\":[0.51565752528"
    "91171,0.5130835356683303,0.5143705304787237]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"num_shots\",\"mta_zone\"],\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"properties\":{\"trim\":{\"type\":\"numbe"
    "r\",\"maximum\":0.5,\"default\":0,\"description\":\"Percentage for robust aver"
    "aging.\",\"minimum\":0},\"num_shots\":{\"type\":\"integer\",\"description\":\"Numb"
    "er of consecutive shots to be used for averaging.\",\"minimum\":1},\"mta_z"
    "one\":{\"type\":\"integer\",\"description\":\"Fixed MTA zone for "
    "averaging.\",\"minimum\":1}},\"title\":\"Waveform Averaging "
    "Settings\",\"description\":\"Settings for waveform averaging\"}"
    ,
    /* example: */
    "{\"trim\":0.05,\"num_shots\":7,\"mta_zone\":1}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"sample_block_file\",\"sample_data_files\"],"
    "\"properties\":{\"range_offset_waveform_samples_m\":{\"type\":\"number\",\"desc"
    "ription\":\"Calibrated device specific range offset for waveform samples"
    " in "
    "meters.\"},\"range_offset_m\":{\"type\":\"number\",\"description\":\"Calibrated "
    "device specific range offset for waveform analysis by system response "
    "fitting in meters.\"},\"sample_data_files\":{\"type\":\"array\",\"items\":{\"typ"
    "e\":\"object\",\"required\":[\"channel\",\"channel_name\",\"sample_interval\",\"sa"
    "mple_bits\",\"laser_wavelength\",\"delta_st\",\"file_extension\"],\"properties"
    "\":{\"delta_st\":{\"type\":\"number\",\"description\":\"reserved\"},\"channel_name"
    "\":{\"type\":\"string\",\"description\":\"Sample block channel name\"},\"channel"
    "\":{\"type\":\"integer\",\"exclusiveMaximum\":false,\"exclusiveMinimum\":false,"
    "\"minimum\":0,\"maximum\":255,\"description\":\"Sample block channel number "
    "(255 = invalid)\"},\"sample_bits\":{\"type\":\"integer\",\"exclusiveMaximum\":f"
    "alse,\"exclusiveMinimum\":false,\"minimum\":0,\"maximum\":32,\"description\":\""
    "Bitwidth of samples (e.g. 10 bit, 12 "
    "bit)\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"},\"sample_interval\":{\"type\":\"number\",\"exc"
    "lusiveMinimum\":false,\"description\":\"Sampling interval in seconds\",\"min"
    "imum\":0},\"laser_wavelength\":{\"type\":\"number\",\"exclusiveMinimum\":false,"
    "\"description\":\"Laser wavelength in meters (0 = unknown)\",\"minimum\":0},"
    "\"file_extension\":{\"type\":\"string\",\"description\":\"Sample data file "
    "extension, without the leading dot\"}}}},\"sample_block_file\":{\"type\":\"o"
    "bject\",\"required\":[\"file_extension\"],\"properties\":{\"file_uuid\":{\"type\""
    ":\"string\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block "
    "file extension, without the leading dot\"}}}},\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"title\":\"Waveform "
    "Information\",\"description\":\"Details about waveform files\"}"
    ,
    /* example: */
    "{\"range_offset_waveform_samples_m \":7.283,\"range_offset_m\":3.1415,\"sam"
    "ple_data_files\":[{\"delta_st\":0,\"channel_name\":\"high_power\",\"channel\":0"
    ",\"file_uuid\":\"da084413-e3e8-4655-a122-071de8490d8e\",\"sample_bits\":12,\""
    "sample_interval\":1.00503e-09,\"laser_wavelength\":0,\"file_extension\":\"sp"
    "0\"},{\"delta_st\":0,\"channel_name\":\"low_power\",\"channel\":1,\"file_uuid\":\""
    "93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"sample_bits\":12,\"sample_interva"
    "l\":1.00503e-09,\"laser_wavelength\":0,\"file_extension\":\"sp1\"},{\"delta_st"
    "\":0,\"channel_name\":\"wwf\",\"channel\":5,\"file_uuid\":\"9d2298c4-1036-464f-b"
    "5cb-1cf8e517f3a0\",\"sample_bits\":12,\"sample_interval\":1.00503e-09,\"lase"
    "r_wavelength\":0,\"file_extension\":\"sp5\"}],\"sample_block_file\":{\"file_uu"
    "id\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\"}}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"description\":\"Scanner settings for waveform output\",\""
    "items\":{\"type\":\"object\",\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_"
    "mask\"],\"properties\":{\"sbl_name\":{\"type\":\"string\",\"description\":\"Name "
    "of sample block, e.g.: wfm, "
    "wwf\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output "
    "enabled\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart "
    "waveform output "
    "enabled\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask"
    " for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold"
    " for deviation greater than "
    "[1]\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for range greater than "
    "[m]\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold for "
    "deviation less than "
    "[1]\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "range less than [m]\"}}},\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"title\":\"Waveform Settings\"}"
    ,
    /* example: */
    "[{\"sbl_name\":\"wfm\",\"enabled\":true,\"smart_enabled\":true,\"channel_idx_ma"
    "sk\":11,\"pass_ampl_less\":5.0,\"pass_ampl_greater\":1.0,\"pass_rng_greater\""
    ":9.27,\"pass_rng_less\":13.11},{\"sbl_name\":\"wwf\",\"enabled\":false,\"channe"
    "l_idx_mask\":32}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"result\",\"filter\",\"settings\"],\"$schema\":\""
    "http://json-schema.org/draft-04/schema#\",\"properties\":{\"filter\":{\"type"
    "\":\"object\",\"required\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_max\""
    "],\"properties\":{\"range_min\":{\"type\":\"array\",\"description\":\"[m]\",\"items"
    "\":{\"type\":\"number\"}},\"range_max\":{\"type\":\"array\",\"description\":\"[m]\",\""
    "items\":{\"type\":\"number\"}},\"angle\":{\"type\":\"array\",\"description\":\"[deg]"
    "\",\"items\":{\"type\":\"number\"}},\"amplitude_max\":{\"type\":\"array\",\"descript"
    "ion\":\"[dB]\",\"items\":{\"type\":\"number\"}}}},\"settings\":{\"type\":\"object\",\""
    "required\":[\"range\",\"amplitude\"],\"properties\":{\"range\":{\"type\":\"object\""
    ",\"required\":[\"sigma_factor\",\"additive_value\"],\"properties\":{\"additive_"
    "value\":{\"type\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}}},\"amplitude"
    "\":{\"type\":\"object\",\"required\":[\"sigma_factor\",\"additive_value\"],\"prope"
    "rties\":{\"additive_value\":{\"type\":\"number\"},\"sigma_factor\":{\"type\":\"num"
    "ber\"}}}}},\"result\":{\"type\":\"object\",\"required\":[\"angle\",\"range_mean\",\""
    "range_sigma\",\"amplitude_mean\",\"amplitude_sigma\",\"amplitude_offset\"],\"p"
    "roperties\":{\"range_mean\":{\"type\":\"array\",\"description\":\"[m]\",\"items\":{"
    "\"type\":\"number\"}},\"amplitude_mean\":{\"type\":\"array\",\"description\":\"[dB]"
    "\",\"items\":{\"type\":\"number\"}},\"amplitude_offset\":{\"type\":\"array\",\"descr"
    "iption\":\"[dB]\",\"items\":{\"type\":\"number\"}},\"amplitude_sigma\":{\"type\":\"a"
    "rray\",\"description\":\"[dB]\",\"items\":{\"type\":\"number\"}},\"timestamp\":{\"ty"
    "pe\":\"array\",\"description\":\"[s]\",\"items\":{\"type\":\"number\"}},\"range_sigm"
    "a\":{\"type\":\"array\",\"description\":\"[m]\",\"items\":{\"type\":\"number\"}},\"ang"
    "le\":{\"type\":\"array\",\"description\":\"[deg]\",\"items\":{\"type\":\"number\"}}}}"
    "},\"title\":\"Window Analysis\",\"description\":\"Window analysis data "
    "estimated from scandata and resulting filter parameters\"}"
    ,
    /* example: */
    "{\"filter\":{\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.21"
    "9,-0.221,-0.223,-0.225,-0.227],\"range_max\":[0.424,0.425,0.426,0.427,0."
    "428,0.428,0.429,0.43,0.431,0.431,0.432],\"angle\":[14.9,15.0,15.1,15.2,1"
    "5.3,15.4,15.5,15.6,15.7,15.8,15.9],\"amplitude_max\":[8.04,8.01,7.99,7.9"
    "6,7.93,7.9,7.88,7.85,7.83,7.8,7.78]},\"settings\":{\"range\":{\"additive_va"
    "lue\":0.1,\"sigma_factor\":8},\"amplitude\":{\"additive_value\":1.0,\"sigma_fa"
    "ctor\":4}},\"result\":{\"range_mean\":[0.1105621,0.1079564,0.1087088,0.1067"
    "261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.1058445,0.10312"
    "61],\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.097782,5.1"
    "16479,5.051756,4.983473,5.007885,5.002441,4.982],\"amplitude_offset\":[1"
    ".9,1.9],\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.4"
    "362353,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],\"t"
    "imestamp\":[408.4441,411.4443],\"range_sigma\":[0.01869652,0.02151435,0.0"
    "1747969,0.01918765,0.01945776,0.01934862,0.01955329,0.02225589,0.02229"
    "977,0.01899122,0.02009433],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5"
    ",15.6,15.7,15.8,15.9]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"required\":[\"amplitude\",\"range\",\"slices\"],\"$schema\":\""
    "http://json-schema.org/draft-04/schema#\",\"properties\":{\"slices\":{\"type"
    "\":\"array\",\"items\":{\"type\":\"object\",\"required\":[\"amplitude\",\"table\"],\"d"
    "escription\":\"Window echo correction parameter "
    "slice\",\"properties\":{\"table\":{\"type\":\"array\",\"description\":\"Correction"
    " table (dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"items\":{\"type\":\"array\",\"description\":\"Table row (= "
    "amplitude "
    "axis)\",\"items\":{\"type\":\"array\",\"maxItems\":3,\"description\":\"Table "
    "column (= range axis)\",\"items\":{\"type\":\"number\",\"description\":\"Table "
    "cell (item 0: amplitude in dB, 1: range in m, 2: flags)\"},\"minItems\":3"
    "},\"minItems\":1},\"minItems\":1},\"amplitude\":{\"type\":\"number\",\"descriptio"
    "n\":\"Window echo amplitude of slice in dB\"}}}},\"range\":{\"type\":\"object\""
    ",\"required\":[\"minimum\",\"maximum\",\"entries\"],\"description\":\"Range axis "
    "of correction "
    "table\",\"properties\":{\"entries\":{\"type\":\"integer\",\"description\":\"Number"
    " of range entries\",\"minimum\":1},\"maximum\":{\"type\":\"number\",\"maximum\":2"
    ".0,\"description\":\"Maximum range in m\",\"minimum\":-2.0},\"minimum\":{\"type"
    "\":\"number\",\"maximum\":2.0,\"description\":\"Minimum range in m\",\"minimum\":"
    "-2.0}}},\"amplitude\":{\"type\":\"object\",\"required\":[\"minimum\",\"maximum\",\""
    "entries\"],\"description\":\"Amplitude axis of correction "
    "table\",\"properties\":{\"entries\":{\"type\":\"integer\",\"description\":\"Number"
    " of amplitude entries\",\"minimum\":1},\"maximum\":{\"type\":\"number\",\"descri"
    "ption\":\"Maximum amplitude in "
    "dB\",\"minimum\":0.0},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "amplitude in dB\",\"minimum\":0.0}}}},\"title\":\"Window Echo "
    "Correction\",\"description\":\"Correction parameters for window glass "
    "echoes\"}"
    ,
    /* example: */
    "{\"slices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\""
    ":1.5},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}"
    "],\"range\":{\"entries\":128,\"maximum\":1.5060822940732335,\"minimum\":-1.506"
    "0822940732335},\"amplitude\":{\"entries\":128,\"maximum\":20,\"minimum\":2}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
